@@ -16,6 +16,7 @@ from orjson import OPT_SERIALIZE_NUMPY, dumps, loads
 from pydantic import BaseConfig, BaseModel, root_validator, validator
 
 from starlite.config.logging import BaseLoggingConfig, LoggingConfig
+from starlite.datastructures.state import State  # noqa: TC001
 from starlite.exceptions import MissingDependencyException
 from starlite.types import BeforeMessageSendHookHandler
 from starlite.utils import AsyncCallable, default_serializer
@@ -34,7 +35,7 @@ except ImportError as e:
     raise MissingDependencyException("sqlalchemy is not installed") from e
 
 if TYPE_CHECKING:
-    from starlite.datastructures.state import State
+
     from starlite.types import Message, Scope
 
 IsolationLevel = Literal["AUTOCOMMIT", "READ COMMITTED", "READ UNCOMMITTED", "REPEATABLE READ", "SERIALIZABLE"]
@@ -310,7 +311,7 @@ class SQLAlchemyConfig(BaseModel):
             )
         return cast("sessionmaker", self.session_maker_instance)
 
-    def create_db_session_dependency(self, state: "State", scope: "Scope") -> Union[Session, AsyncSession]:
+    def create_db_session_dependency(self, state: State, scope: "Scope") -> Union[Session, AsyncSession]:
         """Create a session instance.
 
         Args:
@@ -326,7 +327,7 @@ class SQLAlchemyConfig(BaseModel):
             session = scope[SESSION_SCOPE_KEY] = session_maker()  # type: ignore
         return cast("Union[Session, AsyncSession]", session)
 
-    def update_app_state(self, state: "State") -> None:
+    def update_app_state(self, state: State) -> None:
         """Create a DB engine and stores it in the application state.
 
         Args:
@@ -339,7 +340,7 @@ class SQLAlchemyConfig(BaseModel):
         state[self.engine_app_state_key] = self.engine
         state[self.session_maker_app_state_key] = self.session_maker
 
-    async def on_shutdown(self, state: "State") -> None:
+    async def on_shutdown(self, state: State) -> None:
         """Disposes of the SQLAlchemy engine.
 
         Args:
