@@ -4,7 +4,9 @@ from typing import TYPE_CHECKING, Any, Dict, List, Optional, Tuple, Union, cast
 
 from starlite.connection import Request
 from starlite.constants import DEFAULT_ALLOWED_CORS_HEADERS
-from starlite.datastructures import Headers
+from starlite.datastructures.headers import Headers
+from starlite.datastructures.provide import DependencyCleanupGroup
+from starlite.datastructures.upload_file import UploadFile
 from starlite.enums import HttpMethod, MediaType, ScopeType
 from starlite.exceptions import ImproperlyConfiguredException
 from starlite.handlers.http import HTTPRouteHandler
@@ -13,7 +15,6 @@ from starlite.routes.base import BaseRoute
 from starlite.status_codes import HTTP_204_NO_CONTENT, HTTP_400_BAD_REQUEST
 
 if TYPE_CHECKING:
-
     from starlite.kwargs import KwargsModel
     from starlite.types import ASGIApp, HTTPScope, Method, Receive, Scope, Send
 
@@ -80,6 +81,9 @@ class HTTPRoute(BaseRoute):
         if after_response_handler:
             await after_response_handler(request)  # type: ignore
 
+        if form_data := scope.get("_form", {}):
+            await self._cleanup_temporary_files(form_data=cast("Dict[str, Any]", form_data))
+
     def create_handler_map(self) -> None:
         """Parse the `router_handlers` of this route and return a mapping of
         http- methods and route handlers.
@@ -143,48 +147,58 @@ class HTTPRoute(BaseRoute):
         """
         response_data = None
         before_request_handler = route_handler.resolve_before_request()
+        cleanup_group: Optional["DependencyCleanupGroup"] = None
 
         if before_request_handler:
             response_data = await before_request_handler(request)
 
         if not response_data:
-            response_data = await self._get_response_data(
+            response_data, cleanup_group = await self._get_response_data(
                 route_handler=route_handler, parameter_model=parameter_model, request=request
             )
 
+        response: "ASGIApp"
         if isinstance(response_data, RedirectResponse):
-            return response_data
+            response = response_data
+        else:
+            response = await route_handler.to_response(
+                app=scope["app"],
+                data=response_data,
+                plugins=request.app.plugins,
+                request=request,
+            )
 
-        return await route_handler.to_response(
-            app=scope["app"],
-            data=response_data,
-            plugins=request.app.plugins,
-            request=request,
-        )
+        if cleanup_group:
+            await cleanup_group.cleanup()
+
+        return response  # noqa: R504
 
     @staticmethod
     async def _get_response_data(
         route_handler: "HTTPRouteHandler", parameter_model: "KwargsModel", request: Request
-    ) -> Any:
+    ) -> Tuple[Any, Optional["DependencyCleanupGroup"]]:
         """Determine what kwargs are required for the given route handler's `fn` and calls it."""
         parsed_kwargs: Dict[str, Any] = {}
+        cleanup_group: Optional["DependencyCleanupGroup"] = None
 
-        if parameter_model.has_kwargs:
+        if parameter_model.has_kwargs and route_handler.signature_model:
             kwargs = parameter_model.to_kwargs(connection=request)
 
             if "data" in kwargs:
                 kwargs["data"] = await kwargs["data"]
 
-            for dependency in parameter_model.expected_dependencies:
-                kwargs[dependency.key] = await parameter_model.resolve_dependency(
-                    dependency=dependency, connection=request, **kwargs
-                )
+            cleanup_group = await parameter_model.resolve_dependencies(request, kwargs)
 
-            parsed_kwargs = route_handler.signature_model.parse_values_from_connection_kwargs(connection=request, **kwargs)  # type: ignore
+            parsed_kwargs = route_handler.signature_model.parse_values_from_connection_kwargs(
+                connection=request, **kwargs
+            )
 
-        if route_handler.has_sync_callable:
-            return route_handler.fn.value(**parsed_kwargs)
-        return await route_handler.fn.value(**parsed_kwargs)
+        async with (cleanup_group or DependencyCleanupGroup()):
+            if route_handler.has_sync_callable:
+                data = route_handler.fn.value(**parsed_kwargs)
+            else:
+                data = await route_handler.fn.value(**parsed_kwargs)
+        return data, cleanup_group
 
     @staticmethod
     async def _get_cached_response(request: Request, route_handler: "HTTPRouteHandler") -> Optional["ASGIApp"]:
@@ -303,3 +317,9 @@ class HTTPRoute(BaseRoute):
             http_method=[HttpMethod.OPTIONS],
             include_in_schema=False,
         )(options_handler)
+
+    @staticmethod
+    async def _cleanup_temporary_files(form_data: Dict[str, Any]) -> None:
+        for v in form_data.values():
+            if isinstance(v, UploadFile) and not v.file.closed:
+                await v.close()
