@@ -45,6 +45,7 @@ from .callable_types import (
     AfterRequestHookHandler,
     AfterResponseHookHandler,
     AnyCallable,
+    AnyGenerator,
     AsyncAnyCallable,
     BeforeMessageSendHookHandler,
     BeforeRequestHookHandler,
@@ -88,6 +89,7 @@ __all__ = (
     "AfterRequestHookHandler",
     "AfterResponseHookHandler",
     "AnyCallable",
+    "AnyGenerator",
     "AnyIOBackend",
     "AsyncAnyCallable",
     "BaseScope",
